Rosarivo is a typeface designed for use in letterpress printing. It is an elegant and luxurious typeface with high quality details. It works especially well in delicate editorial design. Its letterpress origins mean it has a lighter color than a typical Roman text type. Its features include carefully designed serifs, gradual stroke and marked contrast, calligraphic and humanistic forms, and large ascenders and descenders. It is designed to work well in long texts with generous line spacing. It originates from work presented to the post-graduate course in Typeface Design at the University of Buenos Aires in 2011.

Rosarivo is a Unicode typeface family that supports languages that use the Latin script and its variants, and could be expanded to support other scripts. To contribute to the project contact Pablo Ugerman.